/*******************************************************************************
* File Name: Coil_Input.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Coil_Input.h"

static Coil_Input_BACKUP_STRUCT  Coil_Input_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: Coil_Input_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function applies only to SIO and USBIO pins.
*  It should not be called for GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet Coil_Input_SUT.c usage_Coil_Input_Sleep_Wakeup
*******************************************************************************/
void Coil_Input_Sleep(void)
{
    #if defined(Coil_Input__PC)
        Coil_Input_backup.pcState = Coil_Input_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            Coil_Input_backup.usbState = Coil_Input_CR1_REG;
            Coil_Input_USB_POWER_REG |= Coil_Input_USBIO_ENTER_SLEEP;
            Coil_Input_CR1_REG &= Coil_Input_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(Coil_Input__SIO)
        Coil_Input_backup.sioState = Coil_Input_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        Coil_Input_SIO_REG &= (uint32)(~Coil_Input_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: Coil_Input_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep(). This 
* function applies only to SIO and USBIO pins. It should not be called for
* GPIO or GPIO_OVT pins.
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to Coil_Input_Sleep() for an example usage.
*******************************************************************************/
void Coil_Input_Wakeup(void)
{
    #if defined(Coil_Input__PC)
        Coil_Input_PC = Coil_Input_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            Coil_Input_USB_POWER_REG &= Coil_Input_USBIO_EXIT_SLEEP_PH1;
            Coil_Input_CR1_REG = Coil_Input_backup.usbState;
            Coil_Input_USB_POWER_REG &= Coil_Input_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(Coil_Input__SIO)
        Coil_Input_SIO_REG = Coil_Input_backup.sioState;
    #endif
}


/* [] END OF FILE */
